/*******************************************************************/
/*                                                                 */
/*   File  :  DIALOG.C                                             */
/*   Author:  Thomas F. Boehm                                      */
/*   Descr.:  External Link Library for MS FoxPro 2.6              */
/*  	      to implement the command DIALOG in the               */
/*	      xBase-Language.                                      */
/*                                                                 */
/*	      Dialog opens a dialogbox with two buttons.           */
/*	      The titlebar of that dialogbox shows the same        */
/*	      title as the application-window.                     */
/*	      Returncode of the function is the number of          */
/*	      the pressed button. (1 or 2)                         */
/*                                                                 */
/*  	      XBASE SYNTAX:                                        */
/*                                                                 */
/*	      SET LIBRARY TO drive:\path\DIALOG.FLL                */
/*	      rc = DIALOG( "bodytext", "button1", "button2")       */
/*                                                                 */
/*   (c)1994  Thomas F. Boehm                                      */
/*	      Schoeneckstr. 25                                     */
/*	      88069 Tettnang                                       */
/*            Germany                                              */
/*                                                                 */
/*            INTERNET: th_boehm@city.eurotel.sub.com              */
/*                                                                 */
/*   This Software is "as-is" and I do not take any                */
/*   responsibility for damage etc caused by this program.         */
/*   This Software is FREEWARE. It may be distributed without fee. */
/*   For any feed-back send an eMail to my Internet-Adress.        */
/*                                                                 */
/*******************************************************************/

#include <pro_ext.h>

FAR Dialog(ParamBlk FAR *parm)
{

  char FAR *bodytext;
  char FAR *button1text;
  char FAR *button2text;
  int  pressedButton;

  if (!_SetHandSize(parm->p[0].val.ev_handle, parm->p[0].val.ev_length + 1))
    _Error(182);
  _HLock(parm->p[0].val.ev_handle);
  if (!_SetHandSize(parm->p[1].val.ev_handle, parm->p[1].val.ev_length + 1))
    _Error(182);
  _HLock(parm->p[1].val.ev_handle);
  if (!_SetHandSize(parm->p[2].val.ev_handle, parm->p[2].val.ev_length + 1))
    _Error(182);
  _HLock(parm->p[2].val.ev_handle);

  bodytext = (char FAR *) _HandToPtr(parm->p[0].val.ev_handle);
  bodytext[parm->p[0].val.ev_length] = '\0';
  button1text = (char FAR *) _HandToPtr(parm->p[1].val.ev_handle);
  button1text[parm->p[1].val.ev_length] = '\0';
  button2text = (char FAR *) _HandToPtr(parm->p[2].val.ev_handle);
  button2text[parm->p[2].val.ev_length] = '\0';

  pressedButton = _Dialog(USER_SCHEME, bodytext, button1text, button2text,
			  (char *)0, 2, 2);

  _HUnLock(parm->p[0].val.ev_handle);
  _HUnLock(parm->p[1].val.ev_handle);
  _HUnLock(parm->p[2].val.ev_handle);

  _RetInt(pressedButton, 10); /* thats the real return value for FOX */
  return(pressedButton);      /* well, thats just to avoid a warning */
}

FoxInfo myFoxInfo[] = {
  {"DIALOG", (FPFI) Dialog, 3, "CCC"},
};

FoxTable _FoxTable = {
  (FoxTable FAR *) 0, sizeof (myFoxInfo) / sizeof (FoxInfo), myFoxInfo
};